<?php
function showIconRPC(&$render,$img,$text,$action,$params) {
	showIcon($render,$img,$text,$action,$params,true);
}

function showIcon(&$render,$img,$text,$action,$params,$rpc=false) {
	$params['action'] = $action;
	$url = $render->actionAndViewURL($params);
	if ($rpc) {
		$rpcURL = $render->urlWithParams("rpc.php",$params);
		$render->show(
			" <a href=\"$url\" onclick=\"return remoteCall('$rpcURL');\" class=\"icon\">",false);
	} else {
		$render->show(" <a href=\"$url\" class=\"icon\">",false);
	}
	$render->show(
		"<img src=\"delete.png\" class=\"icon\" title=\"$text\" alt=\"[$text]\">",
		false);
	$render->show("</a>");
}

function showLink(&$render,$text,$action,$title='',$params,$id='',$rpc=false) {
	if ($id!='') {
		$id = " id=\"$id\"";
	}
	if ($title!='') {
		$title = " title=\"$title\"";
	}
	$params['action'] = $action;
	$url = $render->actionAndViewURL($params);
	if ($rpc) {
		$rpcURL = $render->urlWithParams("rpc.php",$params);
		$render->show(
			"<a${id}${title} href=\"$url\" onclick=\"return remoteCall('$rpcURL');\">",false);
	} else {
		$render->show("<a${id}${title} href=\"$url\" class=\"icon\">",false);
	}
	$render->show("$text</a>");
}
?>